@@ -128,8 +128,7 @@ std::string const &RPiCamApp::CameraId() const
 
 std::string RPiCamApp::CameraModel() const
 {
-	auto model = camera_->properties().get(properties::Model);
-	return model ? *model : camera_->id();
+	return std::string(camera_->properties().get(properties::Model).value_or(camera_->id()));
 }
 
 void RPiCamApp::OpenCamera()
